<?php

declare(strict_types=1);

namespace Drupal\iframe_consent\Entity;

use Drupal\Core\Entity\ContentEntityBase;
use Drupal\Core\Entity\EntityTypeInterface;
use Drupal\Core\Field\BaseFieldDefinition;
use Drupal\Core\Field\FieldStorageDefinitionInterface;
use Drupal\iframe_consent\IframeConsentDomainInterface;

/**
 * Defines the domains entity class.
 *
 * @ContentEntityType(
 *   id = "iframe_consent_domains",
 *   label = @Translation("Domains"),
 *   label_collection = @Translation("Domains"),
 *   label_singular = @Translation("Domain"),
 *   label_plural = @Translation("Domains"),
 *   label_count = @PluralTranslation(
 *     singular = "@count Domain",
 *     plural = "@count Domains",
 *   ),
 *   handlers = {
 *     "list_builder" = "Drupal\iframe_consent\IframeConsentDomainListBuilder",
 *     "views_data" = "Drupal\views\EntityViewsData",
 *     "access" = "Drupal\iframe_consent\IframeConsentDomainAccessControlHandler",
 *     "form" = {
 *       "add" = "Drupal\iframe_consent\Form\IframeConsentDomainForm",
 *       "edit" = "Drupal\iframe_consent\Form\IframeConsentDomainForm",
 *       "delete" = "Drupal\Core\Entity\ContentEntityDeleteForm",
 *       "delete-multiple-confirm" = "Drupal\Core\Entity\Form\DeleteMultipleForm",
 *     },
 *     "route_provider" = {
 *       "html" = "Drupal\iframe_consent\Routing\IframeConsentDomainHtmlRouteProvider",
 *     },
 *   },
 *   base_table = "iframe_consent_domains",
 *   admin_permission = "administer iframe_consent_domains",
 *   entity_keys = {
 *     "id" = "id",
 *     "domain" = "domain",
 *     "label" = "domain",
 *     "uuid" = "uuid",
 *   },
 *   links = {
 *     "collection" = "/admin/config/system/iframe-consent/domains",
 *     "add-form" = "/admin/config/system/iframe-consent/domains/domain/add",
 *     "canonical" = "/admin/config/system/iframe-consent/domains/domain/{iframe_consent_domains}",
 *     "edit-form" = "/admin/config/system/iframe-consent/domains/domain/{iframe_consent_domains}",
 *     "delete-form" = "/admin/config/system/iframe-consent/domains/domain/{iframe_consent_domains}/delete",
 *     "delete-multiple-form" = "/admin/config/system/iframe-consent/domains/domain/delete-multiple",
 *   },
 * )
 */
final class IframeConsentDomain extends ContentEntityBase implements IframeConsentDomainInterface {

  /**
   * {@inheritdoc}
   */
  public static function baseFieldDefinitions(EntityTypeInterface $entity_type): array {

    $fields = parent::baseFieldDefinitions($entity_type);

    $fields['domain'] = BaseFieldDefinition::create('string')
      ->setTranslatable(TRUE)
      ->setLabel(t('Domain'))
      ->setDescription(t('The domain to search for in the iframe src. Should should be https:// and only contain the host'))
      ->setRevisionable(TRUE)
      ->setTranslatable(FALSE)
      ->setRequired(TRUE)
      ->addConstraint('IframeConsentDomain')
      ->setSetting('max_length', 255)
      ->setDisplayOptions('form', [
        'type' => 'string_textfield',
        'weight' => -5,
      ]);

    $fields['consent_groups'] = BaseFieldDefinition::create('list_string')
      ->setLabel(t('Consent groups'))
      ->setDescription(t('The consent groups that will be applied to the iframe. All the consent groups selects will be needed to be accepted by the user to display the iframe.'))
      ->setRevisionable(TRUE)
      ->setTranslatable(FALSE)
      ->setRequired(FALSE)
      ->setCardinality(FieldStorageDefinitionInterface::CARDINALITY_UNLIMITED)
      ->setSetting('allowed_values_function', 'iframe_consent_allowed_values_callback')
      ->setDisplayOptions('form', [
        'type' => 'options_buttons',
        'weight' => 10,
      ]);

    return $fields;
  }

}
