<?php

namespace Drupal\iframe_consent\Service;

use Drupal\Core\Config\ImmutableConfig;

/**
 * Interface for IframeConsentSettings.
 *
 * @package Drupal\iframe_consent\Service
 */
interface IframeConsentSettingsInterface {

  /**
   * Get the consent group label by ID.
   *
   * @param string $id
   *   The domain.
   *
   * @return string
   *   The consent groups label.
   */
  public function getConsentGroupLabelById(string $id): string;

  /**
   * Gets the consent groups list.
   *
   * @return array
   *   The consent groups list.
   */
  public function getConsentGroupsList(): array;

  /**
   * Gets the provider.
   *
   * @return string
   *   The provider.
   */
  public function getProvider(): string;

  /**
   * Gets the iframe consent settings.
   *
   * @return \Drupal\Core\Config\ImmutableConfig
   *   The iframe consent settings.
   */
  public function getSettings(): ImmutableConfig;

  /**
   * Checks if iframe consent is enabled.
   *
   * @return bool
   *   TRUE if iframe consent is enabled, FALSE otherwise.
   */
  public function isEnabled(): bool;

}
